data assimilation - data assimilation module — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »

# data assimilation - data assimilation module

Classes

`ensemble`([ensembles]) | Ensemble-based data assimilation subroutines for the Radiation Belt Model

Functions

`average_window`(PSDdata, Lgrid) | combine observations on same L shell in
`getobs4window`(dd, Tnow) | get observations in time window [Tnow - Twindow, Tnow]
`output`(init, result) | write results to file and be done
`forecast`(Tnow+Twindow) |
`assimilate_JK`(dd) | this version is currently not working
`addmodelerror_old2`(dd, A, y, L) | this routine will add a standard error to the ensemble states
`addmodelerror_old`(dd, A, y, L) | this routine will add a standard error to the ensemble states

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »